@@ -2,6 +2,7 @@ from pathlib import Path
 from palm.plugins.base import BasePlugin
 import pkg_resources
 
+
 def get_version():
     try:
         version = pkg_resources.require("palm-dbt")[0].version
@@ -11,8 +12,8 @@ def get_version():
 
 
 DbtPlugin = BasePlugin(
-    name = 'dbt', 
-    command_dir = Path(__file__).parent / 'commands',
-    version = get_version(),
-    package_location='https://github.com/palmetto/palm-dbt.git'
+    name='dbt',
+    command_dir=Path(__file__).parent / 'commands',
+    version=get_version(),
+    package_location='https://github.com/palmetto/palm-dbt.git',
 )
